@@ -29,6 +29,7 @@ class FlowStateAssignedToChat(AssignedAssetToChat):
     chat_id: StrObjectId = Field()
     next_call: datetime = Field(default_factory=lambda: datetime.now(ZoneInfo("UTC")))
     last_call: Optional[datetime] = Field(default=None)
+    description: str = Field(default="", description="Usefull for AI follow ups where we wanta a specific prompt for the follow up")
     executed_step: int = Field(default=0)
     repeat_step: int = Field(default=0)
     trigger: StateTrigger = Field(default=StateTrigger.NEXT_CALL)
@@ -36,6 +37,7 @@ class FlowStateAssignedToChat(AssignedAssetToChat):
     execution_result: ExecutionResult = Field(default=ExecutionResult.NOT_EXECUTED)
     execution_time_seconds: Optional[float] = Field(default=None)
     error_message: Optional[str] = Field(default=None)
+    last_incoming_message_id: Optional[str] = Field(default=None)
 
     model_config = ConfigDict(
         populate_by_name=True,
@@ -58,13 +60,15 @@ class FlowStateAssignedToChat(AssignedAssetToChat):
         return self.flow_id == other.flow_id and self.chat_id == other.chat_id
 
     @staticmethod
-    def from_link(link: LinkItem, execution_context: ExecutionContext) -> FlowStateAssignedToChat:
+    def from_link(link: LinkItem, execution_context: ExecutionContext, description: str, last_incoming_message_id: Optional[str] = None) -> FlowStateAssignedToChat:
         return FlowStateAssignedToChat(
             flow_id=link.flow_id,
             chat_id=link.chat_id,
             company_id=link.company_id,
             asset_type=ChatAssetType.WORKFLOW,
             assigned_by=execution_context.executor.id,
+            description=description,
+            last_incoming_message_id=last_incoming_message_id
         )
 
     @classmethod
