@@ -66,5 +66,27 @@ class ExecutionContext(BaseModel):
 
     @classmethod
     def from_mega_admin(cls, user: User, company_id: StrObjectId) -> "ExecutionContext":
-        executor = Executor(id=user.id, type=ExecutorType.AGENT, name=user.name)
+        executor = Executor(id=user.id, type=ExecutorType.MEGA_ADMIN, name=user.name)
         return cls(executor=executor, company_id=company_id)
+
+    @classmethod
+    def from_integration(cls, user: User, company_id: StrObjectId) -> "ExecutionContext":
+        executor = Executor(id=user.id, type=ExecutorType.INTEGRATION, name=user.name)
+        return cls(executor=executor, company_id=company_id)
+
+    @property
+    def is_mega_admin(self) -> bool:
+        return self.executor.type == ExecutorType.MEGA_ADMIN
+
+    @property
+    def is_integration(self) -> bool:
+        return self.executor.type == ExecutorType.INTEGRATION
+
+    @property
+    def is_copilot(self) -> bool:
+        return self.executor.type == ExecutorType.COPILOT
+
+
+    @property
+    def user_id(self) -> StrObjectId:
+        return self.executor.id
\ No newline at end of file
