@@ -9,7 +9,7 @@ from ....utils.types.message_types import MessageType
 from bson import ObjectId
 from ....utils import MessageType, Status, MessageSubtype
 from ..schema import ChattyContent, ChattyContext, ChattyReferral
-
+from letschatty.models.utils import StrObjectId
 
 class Message(BaseModel):
     created_at: datetime
@@ -25,6 +25,18 @@ class Message(BaseModel):
     referral: ChattyReferral = Field(default_factory=lambda: ChattyReferral.default())
     context: ChattyContext = Field(default_factory=lambda: ChattyContext.default())
 
+    @property
+    def sent_by_outgoing_id(self) -> StrObjectId:
+        if self.is_incoming_message:
+            raise ValueError("sent_by_outgoing_id is not available for incoming messages")
+        if self.sent_by is None:
+            raise ValueError("sent_by is required for outgoing messages")
+        return self.sent_by
+
+    @property
+    def sent_by_incoming(self) -> bool:
+        return self.is_incoming_message
+
     def __eq__(self, other: Any) -> bool:
         if not isinstance(other, Message):
             return False
