@@ -147,4 +147,12 @@ class InvalidApiKey(CustomException):
 
 class AlreadyCompleted(CustomException):
     def __init__(self, message="Operation already completed", status_code=208, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class ErrorToMantainSafety(CustomException):
+    def __init__(self, message="Raised to mantain safety", status_code=400, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class ResetAIAgentMessage(CustomException):
+    def __init__(self, message="Raised to reset the agent and not answer the user", status_code=400, **context_data):
         super().__init__(message, status_code=status_code, **context_data)
\ No newline at end of file
