@@ -14,15 +14,18 @@ from letschatty.models.chat.highlight import Highlight, HighlightRequestData
 from letschatty.models.chat.quality_scoring import QualityScore
 from letschatty.models.copilot.links import LinkItem
 from letschatty.models.chat.flow_link_state import FlowStateAssignedToChat
+
 from datetime import datetime
 from typing import Dict, Any, Optional, List, TYPE_CHECKING
 from letschatty.models.execution.execution import ExecutionContext
 from letschatty.models.messages.meta_message_model.meta_status_json import ErrorDetail
 from ...models.company.assets.product import Product
-from ...models.company.assets.chat_assets import SaleAssignedToChat, AssignedAssetToChat, ChatAssetType, ContactPointAssignedToChat
+from ...models.company.assets.ai_agents.chatty_ai_agent import ChattyAIAgent
+from ...models.company.assets.ai_agents.chatty_ai_mode import ChattyAIMode
+from ...models.company.assets.chat_assets import SaleAssignedToChat, AssignedAssetToChat, ChatAssetType, ContactPointAssignedToChat, ChattyAIAgentAssignedToChat
 from ...models.chat.scheduled_messages import ScheduledMessageStatus
 from ...models.utils.types.identifier import StrObjectId
-from ...models.utils.custom_exceptions.custom_exceptions import AssetAlreadyAssigned, NotFoundError, MessageAlreadyInChat, MetaErrorNotification, ChatAlreadyAssigned, AlreadyCompleted
+from ...models.utils.custom_exceptions.custom_exceptions import AssetAlreadyAssigned, NotFoundError, MessageAlreadyInChat, MetaErrorNotification, ChatAlreadyAssigned, AlreadyCompleted, ErrorToMantainSafety
 from ..factories.messages.central_notification_factory import CentralNotificationFactory
 from ...models.messages.chatty_messages.schema.chatty_content.content_central import CentralNotificationStatus
 from ...models.messages.chatty_messages.schema import ChattyContext
@@ -160,11 +163,55 @@ class ChatService:
             raise NotFoundError(message=f"Tag with id {tag_id} not found in chat {chat.id}")
 
     @staticmethod
-    def add_workflow_link(chat : Chat, link : LinkItem, flow:FlowPreview, execution_context: ExecutionContext) -> FlowStateAssignedToChat:
+    def add_chatty_ai_agent(chat : Chat, execution_context: ExecutionContext, chatty_ai_agent: ChattyAIAgent, mode_for_chat: Optional[ChattyAIMode] = None) -> AssignedAssetToChat:
+        """
+        Add a chatty ai agent config to the chat.
+        """
+        assigned_ai_agent = ChattyAIAgentAssignedToChat(
+            asset_type=ChatAssetType.CHATTY_AI_AGENT,
+            asset_id=chatty_ai_agent.id,
+            assigned_at=datetime.now(tz=ZoneInfo("UTC")),
+            assigned_by=execution_context.executor.id,
+            mode=mode_for_chat if mode_for_chat else chatty_ai_agent.mode
+        )
+        execution_context.set_event_time(assigned_ai_agent.assigned_at)
+        chat.chatty_ai_agent = assigned_ai_agent
+        ChatService.add_central_notification_from_text(chat=chat, body=f"Agente de IA {chatty_ai_agent.name} agregado al chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.CHATTY_AI_AGENT_ADDED)
+        return assigned_ai_agent
+
+    @staticmethod
+    def remove_chatty_ai_agent(chat : Chat, execution_context: ExecutionContext, chatty_ai_agent: ChattyAIAgent) -> ChattyAIAgentAssignedToChat:
+        """
+        Remove a chatty ai agent from the chat.
+        """
+        if chat.chatty_ai_agent is None:
+            raise NotFoundError(message=f"Chatty AI agent not found in chat {chat.id}")
+        current_chatty_ai_agent = chat.chatty_ai_agent
+        chat.chatty_ai_agent = None
+        execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+        ChatService.add_central_notification_from_text(chat=chat, body=f"Agente de IA {chatty_ai_agent.name} eliminado del chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.CHATTY_AI_AGENT_DELETED)
+        return current_chatty_ai_agent
+
+    @staticmethod
+    def update_chatty_ai_agent(chat : Chat, execution_context: ExecutionContext, chatty_ai_agent_id: StrObjectId,chatty_ai_agent: ChattyAIAgent, mode_for_chat: ChattyAIMode) -> ChattyAIAgentAssignedToChat:
+        """
+        Update a chatty ai agent for the chat.
+        """
+        if chat.chatty_ai_agent is None:
+            raise NotFoundError(message=f"Chatty AI agent not found in chat {chat.id}")
+        if chatty_ai_agent_id != chat.chatty_ai_agent.asset_id:
+            raise NotFoundError(message=f"Chatty AI agent with id {chatty_ai_agent_id} not found in chat {chat.id}")
+        chat.chatty_ai_agent.mode = mode_for_chat
+        execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+        ChatService.add_central_notification_from_text(chat=chat, body=f"Agente de IA {chatty_ai_agent.name} actualizado en el chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.CHATTY_AI_AGENT_UPDATED)
+        return chat.chatty_ai_agent
+
+    @staticmethod
+    def add_workflow_link(chat : Chat, link : LinkItem, flow:FlowPreview, execution_context: ExecutionContext, description: str, last_incoming_message_id: Optional[str] = None) -> FlowStateAssignedToChat:
         """
         Add a tag to the chat.
         """
-        state = FlowStateAssignedToChat.from_link(link, execution_context)
+        state = FlowStateAssignedToChat.from_link(link, execution_context, description, last_incoming_message_id)
         if state in chat.flow_states:
             raise AssetAlreadyAssigned(f"Flow with id {link.flow_id} already assigned to chat {chat.id}")
         execution_context.set_event_time(state.assigned_at)
@@ -195,7 +242,7 @@ class ChatService:
         chat.flow_states.remove(assigned_asset_to_remove)
         bisect.insort(chat.flow_states, workflow_link)
         execution_context.set_event_time(workflow_link.assigned_at)
-        ChatService.add_central_notification_from_text(chat=chat, body=f"Workflow {flow.title} actualizado en el chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.WORKFLOW_UPDATED)
+        # ChatService.add_central_notification_from_text(chat=chat, body=f"Workflow {flow.title} actualizado en el chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.WORKFLOW_UPDATED)
         return workflow_link
 
 
@@ -449,6 +496,8 @@ class ChatService:
         elif current_agent.id == agent_destination.id:
             logger.debug(f"Chat {chat.id} already assigned to {agent_destination.name}")
         elif current_agent.id != execution_context.executor.id: #Chat is already assigned, so its a transfer
+            if execution_context.is_integration:
+                raise ErrorToMantainSafety(f"An integration user is trying to STEAL a chat from {current_agent.name} to {agent_destination.name} | Chat {chat.id} | is {chat.area} | is assigned to {agent_destination.name} by {execution_context.executor.name} | This is a safety warning")
             logger.debug(f"Chat is already assigned, so its a transfer")
             if agent_destination.id != execution_context.executor.id:                 #notify the previous agent and the new one
                 logger.debug(f"Destination is not the executor - So its a transfer")
