@@ -2,8 +2,11 @@ from __future__ import annotations
 from typing import Dict, Type, TYPE_CHECKING
 import logging
 
-from .....models.analytics.sources import WhatsAppDefaultSource, TopicDefaultSource, PureAd, Source, TemplateSource
-from .....models.utils.types.source_types import SourceType
+from .....models.analytics.sources import WhatsAppDefaultSource, TopicDefaultSource, PureAd, Source, TemplateSource, OtherSource
+from .....models.company.assets.ai_agents.chatty_ai_agent_config_for_automation import ChattyAIConfigForAutomation
+from .....models.company.assets.ai_agents.chatty_ai_agent_config_for_automation import ChattyAIMode
+from .....models.utils.types.identifier import StrObjectId
+from .....models.utils.types.source_types import SourceType, SourceCheckerType
 from .helpers import SourceFactoryHelpers
 from datetime import datetime
 from zoneinfo import ZoneInfo
@@ -64,7 +67,6 @@ class SourceFactory:
         description = f"Se creó el anuncio ya que no estaba cargado como fuente de origen. \n Info: {source_url} - {body}"
 
         source_data = {
-            "agent_email": "source_checker@letschatty.com",
             "name": name_for_ad,
             "type": SourceType.PURE_AD,
             "ad_id": ad_id,
@@ -87,7 +89,6 @@ class SourceFactory:
     @staticmethod
     def create_new_impure_ad(message: ChattyMessage, company_id: str, default_flow: str | None = None) -> PureAd:
         source_data = {
-            "agent_email": "source_checker@letschatty.com",
             "name": f"Anuncio Meta Impuro - {message.referral.source_url}",
             "type": SourceType.PURE_AD,
             "ad_id": "provisional_ad_id" + str(ObjectId()),
@@ -108,6 +109,23 @@ class SourceFactory:
             name=f"Template '{template_name}'",
             description=f"Template '{template_name}'",
             trackeable=True,
-            agent_email="source_checker@letschatty.com",
             template_name=template_name
+            )
+
+    @staticmethod
+    def create_literal_source_for_ai_agent_test(company_id: StrObjectId, ai_agent_name: str, chatty_ai_agent_id: StrObjectId, trigger: str) -> OtherSource:
+        return OtherSource(
+            company_id=company_id,
+            created_at=datetime.now(ZoneInfo("UTC")),
+            updated_at=datetime.now(ZoneInfo("UTC")),
+            name=f"Chatty AI Test {ai_agent_name}",
+            description=f"This is a default source for the Chatty AI Agent {ai_agent_name}",
+            trackeable=False,
+            trigger=trigger,
+            source_checker=SourceCheckerType.LITERAL,
+            chatty_ai_agent_config=ChattyAIConfigForAutomation(
+                agent_id=chatty_ai_agent_id,
+                mode=ChattyAIMode.AUTONOMOUS,
+                only_for_new_chats=False
+            ),
         )
\ No newline at end of file
